@@ -17,11 +17,11 @@ depends_on = None
 
 
 def upgrade(engine_name):
-    globals()["upgrade_%s" % engine_name]()
+    globals()[f"upgrade_{engine_name}"]()
 
 
 def downgrade(engine_name):
-    globals()["downgrade_%s" % engine_name]()
+    globals()[f"downgrade_{engine_name}"]()
 
 
 
